#!/usr/bin/perl


$dir_name = $ARGV[0];

use File::Find;
use Cwd;
use SVG::Metadata;

if( $ARGV[1] eq '-v' ){
	$verbose = 1;
}else{
	$verbose = 0;
}


sub process_file {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	
	if ( $full_name !~ /^\// ) {
		$full_name = $current_dir . "/" . $full_name;
	}

	if ( !( -d $full_name) ) {
		if ( $file_name =~ /\.png$/i ) {
			&png_file($file_name, $full_name);
		} elsif ( $file_name =~ /\.xpm$/i ) {
			&xpm_file($file_name, $full_name);
		} elsif ( $file_name =~ /\.svg$/i ) {
			&svg_file($file_name, $full_name);
		} else {
			print "Not a png, xpm, svg: $file_name\n";
		}
	}
}


sub png_file {
	my $file_name = $_[0];
	my $full_name = $_[1];
	my $set = 0;
	if( $verbose ){
		print "PNG: $file_name\n";
		# print "PNG: $file_name\n";
		print "   Displaying Source and License info\n";
	}
	my $text = `identify -verbose $full_name`;
	my @content = split(/\n/,$text);
	foreach $line (@content){
		if ( $line =~ /^ *Source:/ || $line =~ /^ *License:/ || $line =~ /^ *Source_URL:/ ) {
			chomp($line);
			$set = 1;
			if( $verbose ){ print "$line\n"; }
		} 
	}
	if( not $set ){
		print "Error: No License Found!\n";
		print "    $full_name\n";
	}

}


sub xpm_file {
	my $file_name = $_[0];
	my $full_name = $_[1];
	print "XPM: $file_name\n";
	print "   Displaying Source and License info\n";
	if (open(FILE, $full_name)){
		my @lines = <FILE>;
		foreach $line (@lines) {
			if( $line =~ /\/\* License:/ || $line =~ /\/\* Source:/ || $line =~ /\/\* Source URL:/ ) {
				chomp($line);
				$line =~ s/\/\* //;
				$line =~ s/\*\///;
				print "     $line\n";
			}
		}
		close(FILE);
	}
}


sub svg_file {
	my $file_name = $_[0];
	my $full_name = $_[1];
	print "SVG: $file_name\n";
	my $svgmeta = new SVG::Metadata;
	if ($svgmeta->parse($full_name)) {
	print "   title=" . $svgmeta->title() . "\n";
	print "   description=" . $svgmeta->description() . "\n";
	print "   subject=" . $svgmeta->subject() . "\n";
	print "   publisher=" . $svgmeta->publisher() . "\n";
	print "   publisher_url=" . $svgmeta->publisher_url() . "\n";
	print "   creator=" . $svgmeta->creator() . "\n";
	print "   creator_url=" . $svgmeta->creator_url() . "\n";
	print "   owner=" . $svgmeta->owner() . "\n";
	print "   owner_url=" . $svgmeta->owner_url() . "\n";
	print "   license=" . $svgmeta->license() . "\n";
	print "   license_date=" . $svgmeta->license_date() . "\n";
	print "   language=" . $svgmeta->language() . "\n";
	print "   keywords=";
	foreach $keyword ($svgmeta->keywords()){
		print "$keyword, ";
	}
	print "\n";

	}else{
		warn "   Could not parse file: " . $svgmeta->errormsg();
	}
}


# Check input
if( $dir_name eq '' ){
	print "Usage: display_metadata.pl [DIRECTORY] -v\n";
	print "	 [DIRECTORY]: directory searched recusivly, manditory\n";
	print "  -v: verbose, optional, must be placed last\n";
	exit;
} elsif( !( -d $dir_name ) ){
	print "The input ARG is suposta be a directory\n$dir_name\n";
	exit
}


#################################################################
# Main Code
#
#

$current_dir = cwd();
print "Searching for xpm, png, svg, and svgz files in $dir_name\n";
find(\&process_file, $dir_name);

print "\n";
