#!/usr/bin/perl

# you need gs-common, pstoedit and skencil to get this script working
# 
# Usage: eps2svg.pl [EPS FILE]
#
#
# References:
# 	http://wiki.svg.org/PDF2SVG
# 	http://www.calcmaster.net/personal_projects/pdf2svg/
# 	http://frotz.homeunix.org/scripts/eps2svg
#	http://www.rot13.org/~dpavlin/presentations/os2006/

##########################
# Configure
#

$tmp_dir='/tmp/eps2svg';

$delete_tmp_files = '0';



##############################
# Code
#

sub print_usage {
	print <<Endtext;
eps2svg 0.01
  Usage: eps2svg.pl [EPS FILE] 
	or
  Usage: eps2svg.pl [DIRECTORY]
Endtext
}

sub convert_file {
	my $file_name = $_[0];

	my $output_file = $file_name;
	$output_file =~ s/e?ps$/svg/;
	if( -f $output_file ){
		print "  $output_file already exists, skipping convertion\n";
		return;
	}
	print "Converting: $file_name .";
	system("eps2eps -dNOCACHE \"$file_name\" \"$tmp_dir/temp1.eps\"");
	# print "eps2eps -dNOCACHE $file_name $tmp_dir/temp1.eps\n";
	if( -f "$tmp_dir/temp1.eps" ){
		print ".";
		system("pstoedit -f sk \"$tmp_dir/temp1.eps\" \"$tmp_dir/temp2.sk\" > /dev/null 2>&1");
		# print "pstoedit -f sk $tmp_dir/temp1.eps $tmp_dir/temp2.sk\n";
		if( -f "$tmp_dir/temp2.sk"){
			print ".";
			system("skconvert \"$tmp_dir/temp2.sk\" \"$output_file\"");
			print ".\n";
			# print "skconvert $tmp_dir/temp2.sk $output_file\n";
			if( not -f $output_file ){
				print "  Error: skconvert failed for some reason.\n";
				if($delete_tmp_files){ system("rm -f $tmp_dir/*"); }
				return;
			}
		} else {
			print "Error: pstoedit failed for some reason.\n";
			if($delete_tmp_files){ system("rm -f $tmp_dir/*"); }
			return;
		}
	}else{
		print "  Error: eps2eps failed for some reason.\n";
		if($delete_tmp_files){ system("rm -f $tmp_dir/*"); }
		return;
	}
	if($delete_tmp_files){ system("rm -f $tmp_dir/*"); }
}

####################
# Check for problems

# Check for input errors
$error_found = 0;
$file_name = $ARGV[0];
if( $#ARGV > 1 ){ # check if there is more than one arg
	print "Error: too many arguments\n";
	print_usage();
	$error_found = 1;
}
if( $file_name =~ /[\*\?]/ ){ #detect wildcards
	print "Error: sorry wildcards arn't supported, so no \'*\' or \'?\'\n";
	$error_found = 1;
}
# Check if nessasary programs are installed
if( `which eps2eps 2>&1 1>/dev/null` ){
	print "Error: eps2eps is not found in \$PATH\n";
	print "  Ghostscript, includes eps2eps, which is required by eps2svg\n";
	print "  Make sure it is installed, and in \$PATH\n";
	$error_found = 1;	
}
if( `which pstoedit 2>&1 1>/dev/null` ){
	print "Error: ps2edit is not found in \$PATH\n";
	print "  ps2edit is required by eps2svg\n";
	print "  Make sure it is installed, and in \$PATH\n";
	$error_found = 1;	
}
if( `which skconvert 2>&1 1>/dev/null` ){
	print "Error: skconvert is not found in \$PATH\n";
	print "  Skencil, includes skconvert, which is required by eps2svg\n";
	print "  Make sure it is installed, and in \$PATH\n";
	$error_found = 1;	
}
if( $error_found ){	exit 1;} # exit on error
if( $file_name eq '' ){ # no input arg
	print "Error: no input file or directory\n";
	print_usage();
	$error_found = 1;
}elsif( -d $file_name ){ # directory sucseffly detected
	print "Converting all eps files in directory.\n";
	$mode='dir';
	$dir_name = $file_name;
}elsif( -f $file_name && $ARGV[0] =~ /\.e?ps/ ){ # eps file detected
	print "Converting eps files.\n";
	$mode='file';
}else{ # input is not a directory or eps file
	print "Error: input is not a eps file or directory\n";
	$error_found = 1;
}
if( $error_found ){	exit 1;} #exit on error


# create a clean tmp dir
if( -d $tmp_dir ){
	system("rm -f $tmp_dir/*");
}else{
	mkdir($tmp_dir);
}


$has_file = 0;
if( $mode eq 'file' ){ #Convert a file
	convert_file($file_name);
} elsif( $mode eq 'dir' ){ # Convert a directory of files
	opendir(DIR, "$file_name");
	while (defined($file = readdir(DIR))) {
		if( $file =~ /\.e?ps/ ) { # Only do .eps or .ps
			# print "$dir_name/$file\n";
			convert_file("$dir_name/$file");
			$has_file = 1;
		}
	}
	closedir(DIR);
	if( not $has_file ){ 
		print "Error: directory had no eps files.\n";
		exit 1;
	}
}else{
	print "Error is script?\n";
	exit 1;
}


# export BASENAME="`basename $1 .eps`";

# Outline fonts
# eps2eps -dNOCACHE ${BASENAME}.ps ${BASENAME}2.ps

# Fix bounding box
# ps2epsi  ${BASENAME}2.ps  ${BASENAME}3.ps

# Convert to Sketch
# pstoedit -f sk  ${BASENAME}3.ps  ${BASENAME}.sk

# Convert to SVG
# skconvert  ${BASENAME}.sk  ${BASENAME}.svg


print "\n";
