#!/usr/bin/perl

###########################
# Validates images files
# 	supports svg, xpm, png, ico, icns
#
# Description:
#  Recusivly checks all svg, xpm, png, ico, icns images in a dir.
#  svg, xpm, png, ico uses Image magick's identify command.  This 
#  only check to see if images work, it does not find errors. icns 
#  uses libicns's icns2png command, its uncertain what this does.
#
# Requirements:
#  Image Magick: http://www.imagemagick.org/
#  libicns: http://icns.sourceforge.net/
#
# Usage: ./validate_image.pl [DIRECTORY]
#


###########################
# Configure
#

$icns_cmd = '/home/zymos/docs/icons/tools/icns2png -l ';
$ico_cmd = 'identify ';
$tmp_dir = '/tmp/coverting';


###########################
# Code
$dir_name = $ARGV[0];

use File::Find;
use Cwd;
# use SVG::Metadata;


sub process_svg_file {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	
	if ( $full_name !~ /^\// ) {
		$full_name = $current_dir . "/" . $full_name;
	}

	if ( !( -d $full_name) ) {
		if ( $file_name =~ /svg$/ ) {
			my $new = $full_name;
			$new =~ s/svg$/png/;
			print ".";
			system("inkscape -f \"$full_name\" -w 256 -h 256 -e \"$new\" > /dev/null");	
		} else {
			print "x";
		}
	}
}

sub process_png128_file {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	if ( $full_name !~ /^\// ) { $full_name = $current_dir . "/" . $full_name; }
	if ( !( -d $full_name) ) {
		if ( $file_name =~ /png$/ ) {
			print ".";
			system("mogrify -resize 128x128! \"$full_name\"");	
		} else {
			print "x";
		}
	}
}

sub process_png64_file {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	if ( $full_name !~ /^\// ) { $full_name = $current_dir . "/" . $full_name; }
	if ( !( -d $full_name) ) {
		if ( $file_name =~ /png$/ ) {
			print ".";
			system("mogrify -resize 64x64! \"$full_name\"");	
		} else {
			print "x";
		}
	}
}

sub process_png48_file {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	if ( $full_name !~ /^\// ) { $full_name = $current_dir . "/" . $full_name; }
	if ( !( -d $full_name) ) {
		if ( $file_name =~ /png$/ ) {
			print ".";
			system("mogrify -resize 48x48! \"$full_name\"");	
		} else {
			print "x";
		}
	}
}

sub process_png32_file {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	if ( $full_name !~ /^\// ) { $full_name = $current_dir . "/" . $full_name; }
	if ( !( -d $full_name) ) {
		if ( $file_name =~ /png$/ ) {
			print ".";
			system("mogrify -resize 32x32! \"$full_name\"");	
		} else {
			print "x";
		}
	}
}


# Check input
if( $dir_name eq '' ){
	print "Usage: rename.....pl [DIRECTORY]\n";
	exit 1;
} elsif( !( -d $dir_name ) ){
	print "The input ARG is suposta be a directory\n$dir_name\n";
	exit 1;
} elsif( not( -d "$dir_name/svg" ) && not( -d "$dir_name/png" ) ){
	print "There is no svg or png directory\n";
	exit 1;
}


#################################################################
# Main Code
#
#

$current_dir=getcwd;
mkdir("$tmp_dir");
system("rm -rf $tmp_dir/*");
mkdir("$dir_name/png/256x256");
mkdir("$dir_name/png/128x128");
mkdir("$dir_name/png/64x64");
mkdir("$dir_name/png/48x48");
mkdir("$dir_name/png/32x32");

if( -d "$dir_name/svg" ){ # Converting SVG->256x256
	print "Converting svg directory .";
	system("cp -r $dir_name/svg/* $tmp_dir");
	find(\&process_svg_file, $tmp_dir);
	print "\n";
	# exit;
	system("rm -f `find $tmp_dir -name *.svg`");
	system("cp -rn $tmp_dir/ $dir_name/png/256x256");
	if ( -d "$dir_name/png/256x256/coverting/" ){
		system("cp -rn $dir_name/png/256x256/coverting/* $dir_name/png/256x256");
		system("rm -rf $dir_name/png/256x256/coverting/");
	}

	# exit;
	system("rm -rf $tmp_dir/*");
}else{
	print "No svg directory to convert, skipping\n";
}
# exit;
# Converting 256x256->128x128
$size="128x128";
print "Converting $size .";
system("cp -r $dir_name/png/256x256/* $tmp_dir");
find(\&process_png128_file, $tmp_dir);
print "\n";
system("cp -rn $tmp_dir/ $dir_name/png/$size/");
if ( -d "$dir_name/png/$size/coverting/" ){
	system("cp -rn $dir_name/png/$size/coverting/* $dir_name/png/$size");
	system("rm -rf $dir_name/png/$size/coverting/");
}
# exit;
system("rm -rf $tmp_dir/*");

$size="64x64";
print "Converting to 64x64 .";
system("cp -r $dir_name/png/256x256/* $tmp_dir");
system("cp -r $dir_name/png/128x128/* $tmp_dir");
find(\&process_png64_file, $tmp_dir);
print "\n";
system("cp -rn $tmp_dir/ $dir_name/png/64x64/");
if ( -d "$dir_name/png/$size/coverting/" ){
	system("cp -rn $dir_name/png/$size/coverting/* $dir_name/png/$size");
	system("rm -rf $dir_name/png/$size/coverting/");
}
system("rm -rf $tmp_dir/*");

$size="48x48";
print "Converting to 48x48 .";
system("cp -r $dir_name/png/256x256/* $tmp_dir");
system("cp -r $dir_name/png/128x128/* $tmp_dir");
system("cp -r $dir_name/png/64x64/* $tmp_dir");
find(\&process_png48_file, $tmp_dir);
print "\n";
system("cp -rn $tmp_dir/ $dir_name/png/48x48/");
if ( -d "$dir_name/png/$size/coverting/" ){
	system("cp -rn $dir_name/png/$size/coverting/* $dir_name/png/$size");
	system("rm -rf $dir_name/png/$size/coverting/");
}
system("rm -rf $tmp_dir/*");

$size="32x32";
print "Converting to 32x32 .";
system("cp -r $dir_name/png/256x256/* $tmp_dir");
system("cp -r $dir_name/png/128x128/* $tmp_dir");
system("cp -r $dir_name/png/64x64/* $tmp_dir");
system("cp -r $dir_name/png/48x48/* $tmp_dir");
find(\&process_png32_file, $tmp_dir);
print "\n";
system("cp -rn $tmp_dir/ $dir_name/png/32x32/");
if ( -d "$dir_name/png/$size/coverting/" ){
	system("cp -rn $dir_name/png/$size/coverting/* $dir_name/png/$size");
	system("rm -rf $dir_name/png/$size/coverting/");
}
system("rm -rf $tmp_dir/*");


print "\n";
