#!/usr/bin/perl


# Converters don't support 256x256


$del_old = 1; #delete old ico and icns dirs
$del_tmp_files = 1; #delete temp files
$png2ico_cmd = 'icotool -c -o';
$png2icns_cmd = 'png2icns';

$dir_name = $ARGV[0];

use File::Find;
use Cwd;
# use SVG::Metadata;


sub process_file_ico {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	if ( $full_name !~ /^\// ) { #making it a full path
		$full_name = $current_dir . "/" . $full_name;
	}
	my $ico_name = $full_name;
	$ico_name =~ s/png$/ico/;
	if ( !( -d $full_name) ) {
		if ( $file_name =~ /\.png$/i ) {
			print "w";
			$error_out = `$png2ico_cmd $ico_name $full_name 2>&1 1>/dev/null`;
			if( $error_out ){
				print "   ICO Convertion failed!!\n";
				print "   $error_out\n";
				unlink($ico_name);
			}
		} else {
			# print "Not a png: $file_name, doesn't belong here!\n";
		}
	}
}
sub process_file_icns {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	
	if ( $full_name !~ /^\// ) { #making it a full path
		$full_name = $current_dir . "/" . $full_name;
	}

	my $icns_name = $full_name;
	$icns_name =~ s/png$/icns/;

	if ( !( -d $full_name) ) {
		if ( $file_name =~ /\.png$/i ) {
			print "m";
			$error_out = `$png2icns_cmd $icns_name $full_name 2>&1 1>/dev/null`;
			if( $error_out ){
				print "   ICNS Convertion failed!!\n";
				print "   $error_out\n";
				unlink($icns_name);
			}
		} else {
			# print "Not a png: $file_name, doesn't belong here!\n";
		}
	}
}

sub clean_files {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	
	if ( $full_name !~ /^\// ) { #making it a full path
		$full_name = $current_dir . "/" . $full_name;
	}
	if ( !( -d $full_name) ) {
		if ( not ($file_name =~ /\.ico$/i) && not ($file_name =~ /\.icns$/i) ) {
			# print "Removing temp file: $file_name.\n";
			unlink("$full_name");
		}
	}
}

# Check input
if( $dir_name eq '' ){
	print "Usage: display_metadata.pl [DIRECTORY]\n";
	exit 1;
} elsif( !( -d $dir_name ) ){
	print "The input ARG is suposta be a directory\n$dir_name\n";
	exit 1;
} elsif( !( -d "$dir_name/png" ) ){
	print "No png dir found\n";
	exit 1;
}


#################################################################
# Main Code
#
#

###############################
# Makiung and copying dirs
$current_dir = cwd();
$ico_dir = "$dir_name/ico";
$icns_dir = "$dir_name/icns";
if( $del_old && -d $ico_dir ){
	print "Deleting old ico files\n";
	system("rm -rf $ico_dir");
}
if( $del_old && -d $icns_dir ){
	print "Deleting old icns files\n";
	system("rm -rf $icns_dir");
}
mkdir("$ico_dir");
mkdir("$icns_dir");

$set = 0;
opendir(DIR, "$dir_name/png");
while (defined($file = readdir(DIR))) {
	print "$file\n";
	if( not( $file eq '.' || $file eq '..') && $file =~ /16x16|32x32|48x48/ && -d "$dir_name/png/$file" ) {
		print "Found $file folder. Copying files to icns dirs.\n";
		# system("cp -R $dir_name/png/$file $ico_dir");
		system("cp -R $dir_name/png/$file $icns_dir");
		$set = 1;
	}
	if( not( $file eq '.' || $file eq '..') && $file =~ /16x16|22x22|24x24|32x32|48x48/ && -d "$dir_name/png/$file" ) {
		print "Found $file folder. Copying files to ico.\n";
		system("cp -R $dir_name/png/$file $ico_dir");
		# system("cp -R $dir_name/png/$file $icns_dir");
		$set = 1;
	}

}
closedir(DIR);



###############################
# Conversion
if( $set ){
	print "Converting to ico in $dir_name\n";
	find(\&process_file_ico, $ico_dir);
	print "Converting to icns in $dir_name\n";
	find(\&process_file_icns, $icns_dir);
	if( $del_tmp_files ){
		print "Cleaning up temp files\n";
		find(\&clean_files, $ico_dir);
		find(\&clean_files, $icns_dir);
	}
} else {
	print "Error: no (16x16|32x32|48x48|64x64|128x128|256x256) directories found\n";
	exit 1;
}
print "\n";
