#!/usr/bin/perl 
#

###########################################################
# Add Source and licence info into PNG, XPM, and SVG files
#
#
# Usage: 
# 	add_metadata.pl "[LICENCE]" "[SOURCE]" "[SOURCE URL]" [DIRECTORY]
#
# Example: 
# 	add_metadata.pl "CC-BY-3.0" "Happy Icons" "http://www.happy.com" icons/
#
# Example (without URL):
# 	add_metadata.pl "CC-BY-3.0" "Happy Icons" "" icons/
#

$license = $ARGV[0];
$license_url = $ARGV[1];
$source = $ARGV[2];
$source_url = $ARGV[3];
$dir_name = $ARGV[4];


use File::Find;
use Cwd;
use SVG::Metadata; 
use XML::Twig;     # Needed if SVG::Metadata fails, to get XML twig to attach new RDF to.

sub process_file {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	
	if ( $full_name !~ /^\// ) {
		$full_name = $current_dir . "/" . $full_name;
	}
	# print "$full_name\n";
	if ( !( -d $full_name) ) {
		if ( $file_name =~ /\.png$/i ||$file_name =~ /\.xpm$/i ||$file_name =~ /\.svg$/i ) {
			make_file($file_name,$full_name);
		} else {
			print "Not a png, xpm, svg, svgz: $file_name\n";
		}
	}
}


sub make_file {
	my $file_name = $_[0];
	my $full_name = $_[1];
	my $license_full_name = $full_name . ".license";
	if( -f $license_full_name ) { unlink($license_full_name); }
	if(open(FILE, ">$license_full_name")) {
		print "+";
		print FILE "$license () $license_url () $source () $source_url\n";
		close FILE;
	} else {
		print "ERROR: could not write file\n";
	}
}




# Check input
if( $license eq '' ){
	print "Input ARGS: LICENSE LICENSE_URL SOURCE SOURCE_URL DIRECTORY\n";
	exit 1;
} elsif( !( -d $dir_name ) ){
	print "The 4rd input ARG is suposta be a directory\n$dir_name\n";
	exit 1;
}elsif( !( -d ($dir_name . "/png") || -d ($dir_name . "/xpm") ) ){
	print "Not in right place directory\n$dir_name\n";
	exit 1;
}



#################################################################
# Main Code
#
#
$current_dir = cwd();
find(\&process_file, $dir_name);

print "\n";
