#!/usr/bin/perl 
#

###########################################################
# Add Source and licence info into PNG, XPM, and SVG files
#
#
# Usage: 
# 	add_metadata.pl "[LICENCE]" "[SOURCE]" "[SOURCE URL]" [DIRECTORY]
#
# Example: 
# 	add_metadata.pl "CC-BY-3.0" "Happy Icons" "http://www.happy.com" icons/
#
# Example (without URL):
# 	add_metadata.pl "CC-BY-3.0" "Happy Icons" "" icons/
#

use File::Find;
use Cwd;
# use SVG::Metadata; 
# use XML::Twig;     # Needed if SVG::Metadata fails, to get XML twig to attach new RDF to.


$license_intro_file = 'open_icon_library-devel/docs/templates/single_file_license_intro.txt';


$source[0] = 'aem';
$license[0] = 'PD';

$source[1] = 'cc';
$license[1] = 'CC-BY 3.0';

$source[2] = 'crystal_clear';
$license[2] = 'LGPL-2.1';

$source[3] = 'crystal';
$license[3] = 'LGPL-2.1';

$source[4] = 'din';
$license[4] = 'PD';

$source[5] = 'famfamfam-flag';
$license[5] = 'PD';

$source[6] = 'famfamfam-silk';
$license[6] = 'CC-BY-2.5 or CC-BY-3.0';

$source[7] = 'ghs';
$license[7] = 'PD';

$source[8] = 'gnome';
$license[8] = 'GPLv2';

$source[9] = 'gnome_colors';
$license[9] = 'GPLv2';

$source[10] = 'intrigue';
$license[10] = 'GPLv2';

$source[11] = 'nuvola';
$license[11] = 'LGPL-2.1';

$source[12] = 'nps';
$license[12] = 'PD';

$source[13] = 'open_clip_art_library';
$license[13] = 'PD';

$source[14] = 'homemade';
$license[14] = 'PD';

$source[15] = 'oxygen';
$license[15] = 'CC-BY-SA 3.0 or LGPL';

$source[16] = 'tango';
$license[16] = 'PD';

$source[17] = 'tango-harm';
$license[17] = 'CC-BY 3.0';

$source[18] = 'warthan';
$license[18] = 'GPL';

$source[19] = 'wiki_commons_bsd';
$license[19] = 'BSD';

$source[20] = 'wiki_commons_mit';
$license[20] = 'MIT';

$source[21] = 'wiki_commons_cc';
$license[21] = 'See Below';

$source[22] = 'wiki_commons_gpl';
$license[22] = 'See Below';

$source[23] = 'wiki_commons_pd';
$license[23] = 'PD';

$source[24] = 'wpclipart';
$license[24] = 'PD';

$source[24] = 'app-install';
$license[24] = 'See Below';

$source_by_subject[0] = 'fineicons';
$license_by_subject[0] = 'CC-BY-SA-2.0-UK';

$source_by_subject[1] = 'gimp';
$license_by_subject[1] = 'GPLv2';

$source_by_subject[2] = 'inkscape';
$license_by_subject[2] = 'GPLv2';

$source_by_subject[3] = 'openoffice';
$license_by_subject[3] = 'GPLv3';


sub read_dirs {
	$x=0;
	while( $source[$x] ne '' ){
		my $dir_name = $current_dir . '/open_icon_library-devel/icons/' . $source[$x];
		find(\&process_file, $dir_name);
		$x++;
	}
	$x=0;
	while( $source_by_subject[$x] ne '' ){
		my $dir_name = $current_dir . '/open_icon_library-devel/icons_by_subject/' . $source_by_subject[$x];
		find(\&process_file, $dir_name);
		$x++;
	}

}


sub process_file {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	
	if ( $full_name !~ /^\// ) {
		$full_name = $current_dir . "/" . $full_name;
	}
	# print "$full_name\n";
	if ( !( -d $full_name) ) {
		if ( $file_name =~ /\.png$/i ||$file_name =~ /\.xpm$/i ||$file_name =~ /\.svg$/i ||$file_name =~ /\.ico$/i ||$file_name =~ /\.icns$/i ) {
			$file_list[$cnt] = "$file_name / $source[$x] / $license[$x]\n";
			$cnt++;
		} 
	}
}


# sub make_file {
	# my $file_name = $_[0];
	# my $full_name = $_[1];
	# my $license_full_name = $full_name . ".license";
	# if( -f $license_full_name ) { unlink($license_full_name); }
	# if(open(FILE, ">$license_full_name")) {
		# print "+";
		# print FILE "$license () $license_url () $source () $source_url\n";
		# close FILE;
	# } else {
		# print "ERROR: could not write file\n";
	# }
# }




# # Check input
# if( $license eq '' ){
	# print "Input ARGS: LICENSE LICENSE_URL SOURCE SOURCE_URL DIRECTORY\n";
	# exit 1;
# } elsif( !( -d $dir_name ) ){
	# print "The 4rd input ARG is suposta be a directory\n$dir_name\n";
	# exit 1;
# }elsif( !( -d ($dir_name . "/png") || -d ($dir_name . "/xpm") ) ){
	# print "Not in right place directory\n$dir_name\n";
	# exit 1;
# }



#################################################################
# Main Code
#
#
$current_dir = cwd();
$x = 0;
$cnt = 0;
$output_text = '';
$output_text_head = '';
$output_text_head_gpl = '';
$output_text_head_cc = '';
$output_text_head_pd = '';
$output_text_wiki = '';
$output_text_cc = '';
$output_text_gpl = '';
$output_text_pd = '';
$output_text_win = '';
$output_text_mac = '';
$output_text_std = '';
$output_text_wiki = '';
$output_text_wiki_gpl = '';
$output_text_wiki_cc = '';
$output_text_wiki_pd = '';
$output_text_app_install = '';


open FILE, "open_icon_library-devel/docs/templates/single_file_license_intro.txt" or die $!;
while (<FILE>) { 
	$output_text_head .= $_; 
}
close FILE;

open FILE, "open_icon_library-devel/docs/templates/single_file_license_intro_gpl.txt" or die $!;
while (<FILE>) { 
	$output_text_head_gpl .= $_; 
}
close FILE;

open FILE, "open_icon_library-devel/docs/templates/single_file_license_intro_cc.txt" or die $!;
while (<FILE>) { 
	$output_text_head_cc .= $_; 
}
close FILE;

open FILE, "open_icon_library-devel/docs/templates/single_file_license_intro_pd.txt" or die $!;
while (<FILE>) { 
	$output_text_head_pd .= $_; 
}
close FILE;


# Reading all image files
read_dirs();
%hashTemp = map { $_ => 1 } @file_list;
@array_out = sort keys %hashTemp;
foreach $content (@array_out){
	$output_text .= $content;
	if( $content  =~ /GPL/ ){
		$output_text_gpl .= $content;
	}
	if( $content =~ /CC/ ){
		$output_text_cc .= $content;
	}
	if( $content =~ /PD/ ){
		$output_text_pd .= $content;
	}
	if( $content =~ /\.ico/ ){
		$output_text_win .= $content;
	}
	if( $content =~ /\.icns/ ){
		$output_text_mac .= $content;
	}
	if($content =~ /\.ico/ || $content =~ /\.png/ ){
		$output_text_std .= $content;
	}

}



# Wiki Commons BSD
$output_text_wiki .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (BSD Licenses)\n\n";

open FILE, "open_icon_library-devel/docs/AUTHORS_wiki_commons_BSD" or die $!;
while (<FILE>) { 
	$output_text_wiki .= $_; 
}
close FILE;



# Wiki Commons CC
$output_text_wiki .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (CC Licenses)\n#\n\n";
$output_text_wiki_cc .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (CC Licenses)\n#\n\n";
open FILE, "open_icon_library-devel/docs/AUTHORS_wiki_commons_CC" or die $!;
while (<FILE>) { 
	$output_text_wiki .= $_; 
	$output_text_wiki_cc .= $_; 
}
close FILE;



# Wiki Commons GPL
$output_text_wiki .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (GPL Licenses)\n#\n\n";
$output_text_wiki_gpl .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (GPL Licenses)\n#\n\n";
open FILE, "open_icon_library-devel/docs/AUTHORS_wiki_commons_GPL" or die $!;
while (<FILE>) { 
	$output_text_wiki .= $_; 
	$output_text_wiki_gpl .= $_; 	
}
close FILE;


# Wiki Commons MIT
$output_text_wiki .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (MIT Licenses)\n#\n\n";

open FILE, "open_icon_library-devel/docs/AUTHORS_wiki_commons_MIT" or die $!;
while (<FILE>) { 
	$output_text_wiki .= $_; 
}
close FILE;



# Wiki Commons PD
$output_text_wiki .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (PD Licenses)\n#\n\n";
$output_text_wiki_cc .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (PD Licenses)\n#\n\n";
$output_text_wiki_pd .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (PD Licenses)\n#\n\n";
$output_text_wiki_gpl .= "\n\n\n#################################################################\n## Wiki Commons authors and licenses information (PD Licenses)\n#\n\n";
open FILE, "open_icon_library-devel/docs/AUTHORS_wiki_commons_PD" or die $!;
while (<FILE>) { 
	$output_text_wiki .= $_; 
	$output_text_wiki_cc .= $_; 
	$output_text_wiki_pd .= $_; 
	$output_text_wiki_gpl .= $_; 
}
close FILE;



# app-install
$output_text_app_install = "\n\n\n#################################################################\n## app-install authors and licenses information \n#\n\n";

open FILE, "open_icon_library-devel/docs/AUTHORS_app-install" or die $!;
while (<FILE>) { 
	$output_text_app_install.= $_; 

}
close FILE;


########################################
## Writing file
open FILE, ">open_icon_library-devel/LICENSES_full_documentation.txt" or die $!;
print FILE $output_text_head; 
print FILE $output_text; 
print FILE $output_text_wiki;
print FILE $output_text_app_install;
close FILE;

open FILE, ">open_icon_library-devel/LICENSES_full_documentation_gpl.txt" or die $!;
print FILE $output_text_head_gpl; 
print FILE $output_text_gpl; 
print FILE $output_text_wiki_gpl; 
close FILE;

open FILE, ">open_icon_library-devel/LICENSES_full_documentation_cc.txt" or die $!;
print FILE $output_text_head_cc; 
print FILE $output_text_cc; 
print FILE $output_text_wiki_cc; 
close FILE;

open FILE, ">open_icon_library-devel/LICENSES_full_documentation_pd.txt" or die $!;
print FILE $output_text_head_pd; 
print FILE $output_text_pd; 
print FILE $output_text_wiki_pd; 
close FILE;

open FILE, ">open_icon_library-devel/LICENSES_full_documentation_win.txt" or die $!;
print FILE $output_text_head; 
print FILE $output_text_win; 
print FILE $output_text_wiki; 
close FILE;

open FILE, ">open_icon_library-devel/LICENSES_full_documentation_mac.txt" or die $!;
print FILE $output_text_head; 
print FILE $output_text_mac; 
print FILE $output_text_wiki; 
close FILE;

open FILE, ">open_icon_library-devel/LICENSES_full_documentation_std.txt" or die $!;
print FILE $output_text_head; 
print FILE $output_text_std; 
print FILE $output_text_wiki; 
close FILE;

print "\nall done.\n";
