#!/usr/bin/perl -w
#

use SVG::Metadata;
use XML::Twig;     # Needed if SVG::Metadata fails, to get XML twig to attach new RDF to.


sub processfile {
  for $f (@_) {
	  print "processing file $f\n";
    my $meta = new SVG::Metadata;
    my $p; eval { $p = $meta->parse($f, retain_xml => 1) };
    if ($p) {
		print "reading current metadata\n";
      # We merge the image's own metadata with the propagated
      # metadata.  The file's own metadata, where present, take
      # precedence, but keywords are used from both sources.
      eval " \$meta->$_(\$mainmeta->$_()) unless \$meta->$_() "
        for qw(title description publisher publisher_url creator
               creator_url owner owner_url license license_date
               about_url date language);
      # $meta->addKeyword($mainmeta->keywords());
	  my $blip = '';
	  if( $meta->publisher() ) {
		  $blip = ', ';
	  }
	  my $added_source = $meta->publisher() . $blip . "Source: $source";
	  $meta->publisher($added_source);
      my @k = $meta->keywords();
	  if( $meta->license() ) {
		  $meta->license($license)
	  }
      $meta->removeKeyword('unsorted') if @k > 1;
      writemetatofile($meta, $f);
    } else {
		print "doesn't have metadata yet, creating now\n";
      # The image has no metadata of its own, so give it the
      # propagated metadata unaltered:
      writemetatofile($mainmeta, $f);
    }
  }
}



sub get_xml {
  my ($file) = @_;
    my $twig = XML::Twig->new( map_xmlns => {
              'http://web.resource.org/cc/' => "cc",
              'http://www.w3.org/1999/02/22-rdf-syntax-ns#' => "rdf",
              'http://purl.org/dc/elements/1.1/' => "dc",
              'http://www.w3.org/2000/svg' => "svg",
       },
       pretty_print => 'indented',
       comments     => 'keep',
       pi           => 'keep',
       keep_original_prefix => 1,
    );
  eval { $twig->parsefile($file); };
  if ($@) {
    warn "XML::Twig hates $file: $@"; return;
  }
  return $twig;
}


sub writemetatofile {
  my ($meta, $file, $svg) = @_;
  $svg ||= $meta->to_svg();
  if (not $svg) {
	  print "writing newstuff method 1\n";
    warn "Processing $file\n";
    my $xml = get_xml($file);
    #my $mdx = get_xml('metadata.rdf');
    my $mdx = XML::Twig->new(map_xmlns => {
                  'http://web.resource.org/cc/' => "cc",
                  'http://www.w3.org/1999/02/22-rdf-syntax-ns#' => "rdf",
                  'http://purl.org/dc/elements/1.1/' => "dc",
        },
        pretty_print => 'indented',
    );
    $mdx->parse($meta->to_rdf());
    if (ref $xml and ref $mdx) {
      $mdx->root()->copy();
      $mdx->root()->paste( first_child => $xml->root());
      open SVGIN, '<', $file; local $/ = '<svg'; my $raw = <SVGIN>; close SVGIN;
      my ($decl) = $raw =~ /(.*?)(<svg|<!-- Created|<!-- Generator|$)/is; # an inexact science
      my $newsvg = $decl . ($xml->root()->sprint());
      if ($newsvg) {
		  print "write method 2\n";
        writemetatofile($meta, $file, $newsvg);
      } else {
        warn "Processing failed on $file"; return;
      }
    } else {
      warn "Cannot process $file"; return;
    }
  } elsif (open SVG, '>:encoding(utf8)', $file) {
	print "Writing method 3\n";
	print SVG $svg; close SVG;
  } else { warn "cannot write $file: $!\n"; }
}

$license = "GPLv2";
$source = "Deathrow Happy fart";
$mainmeta = new SVG::Metadata;
# $mainmeta->parse('metadata.rdf') # do not retain_xml here.
  # or die "Could not parse metadata.rdf: " . $mainmeta->errormsg() . "\n";
# if ( (not $mainmeta->publisher()) and
	 # (not $mainmeta->publisher_url()) ) {
  $mainmeta->publisher('Deathrow');
  $mainmeta->license($license);
# }

processfile($ARGV[0]);


 # my $svgmeta = new SVG::Metadata;
# $svgmeta->retain_xml('1') or die "Could not parse $filename: " . $svgmeta->errormsg();

 # $svgmeta->parse($ARGV[0], retain_xml => 1)     or die "Could not parse $filename: " . $svgmeta->errormsg();


 # $svgmeta->retain_xml($ARGV[0]);

 # print $svgmeta->license() . "=licence\n";
 # print $svgmeta->publisher() . "=put\n";

# $svgmeta->license('GPLv2');
# $svgmeta->publisher('Creative Com');
 # $svgmeta->retain_xml($ARGV[0]);
 # print $svgmeta->license() . "=licence\n";
 # print $svgmeta->publisher() . "=put\n";

# $svg ||= $svgmeta->to_svg();
# if (not $svg) {
	# print "ERROR\n";
# }
 # print $svgmeta->to_text();
# $svgmeta->to_svg() or die "Could not parse $filename: " . $svgmeta->errormsg();
print "\n";
