#!/usr/bin/perl

###########################
# Validates images files
# 	supports svg, xpm, png, ico, icns
#
# Description:
#  Recusivly checks all svg, xpm, png, ico, icns images in a dir.
#  svg, xpm, png, ico uses Image magick's identify command.  This 
#  only check to see if images work, it does not find errors. icns 
#  uses libicns's icns2png command, its uncertain what this does.
#
# Requirements:
#  Image Magick: http://www.imagemagick.org/
#  libicns: http://icns.sourceforge.net/
#
# Usage: ./validate_image.pl [DIRECTORY]
#


###########################
# Configure
#

$icns_cmd = '/home/zymos/docs/icons/tools/icns2png -l ';
$ico_cmd = 'identify ';



###########################
# Code
$dir_name = $ARGV[0];

use File::Find;
use Cwd;
use SVG::Metadata;


sub process_file {
    my $file_name=$_;
	my $full_name = $File::Find::name;
	
	if ( $full_name !~ /^\// ) {
		$full_name = $current_dir . "/" . $full_name;
	}

	if ( !( -d $full_name) ) {
		if ( $file_name =~ /\.png$/i ) {
			&png_file($file_name, $full_name);
		} elsif ( $file_name =~ /\.xpm$/i ) {
			&xpm_file($file_name, $full_name);
		} elsif ( $file_name =~ /\.svg$/i ) {
			&svg_file($file_name, $full_name);
		} elsif ( $file_name =~ /\.ico$/i ) {
			&ico_file($file_name, $full_name);
		} elsif ( $file_name =~ /\.icns$/i ) {
			&icns_file($file_name, $full_name);
		} elsif ( $file_name =~ /\.license$/i ) {
			# ignore
		} else {
			print "Not a png, xpm, svg, ico, icns: $file_name\n";
		}
	}
}


sub png_file {
	my $file_name = $_[0];
	my $full_name = $_[1];
	# print "PNG: $file_name\n";
	# print "PNG: $file_name\n";
	# print "   Displaying Source and License info\n";
	my $text = `identify $full_name 2>&1 1>/dev/null`;
	# print $text;
	if ( $text ) {
		# chomp($text);
		# print "$full_name\n";
		# chop($text);
		# $text =~ s/\W//g;
		# $text =~ s/\`.*//;
		# print "PNG broken:\n  $full_name\n  $text\n";
		# print " .";
		print "\nPNG Broken!!!: $file_name\n";
		print FILE "$full_name\n";
	}else{
		print "p";
	}

}

sub ico_file {
	my $file_name = $_[0];
	my $full_name = $_[1];
	my $text = `$ico_cmd $full_name 2>&1 1>/dev/null`;
	# print $text;
	if ( $text ) {
		print "\nICO Broken!!!: $file_name\n";
		print FILE "$full_name\n";
	}else{
		print "W";
	}

}

sub icns_file {
	my $file_name = $_[0];
	my $full_name = $_[1];
	my $text = `$icns_cmd $full_name 2>&1 1>/dev/null`;
	# print $text;
	if ( $text ) {
		print "\nICNS Broken!!!: $file_name\n";
		print FILE "$full_name\n";
	}else{
		print "m";
	}

}


sub xpm_file {
	my $file_name = $_[0];
	my $full_name = $_[1];
	my $text = `identify $full_name 2>&1 1>/dev/null`;
	# print $text;
	if ( $text ) {
		print "\nXPM Broken!!!: $file_name\n";
		print FILE "$full_name\n";
	}else{
		print "x";
	}

}


sub svg_file {
	my $file_name = $_[0];
	my $full_name = $_[1];
	my $text = `identify $full_name 2>&1 1>/dev/null`;
	# print $text;
	if ( $text ) {
		print "\nSVG Broken!!!: $file_name\n";
		print FILE "$full_name\n";
	}else{
		print "s";
	}
}


# Check input
if( $dir_name eq '' ){
	print "Usage: display_metadata.pl [DIRECTORY]\n";
	exit;
} elsif( !( -d $dir_name ) ){
	print "The input ARG is suposta be a directory\n$dir_name\n";
	exit
}


#################################################################
# Main Code
#
#

open(FILE,">broken_images.log");
$current_dir = cwd();
print "Searching for xpm, png, svg, and svgz files in $dir_name\n";
find(\&process_file, $dir_name);
close(FILE);

print "\nList of broken file in broken_images.log\n";
print "\n";
